@@ -34,10 +34,11 @@ class Dist::Zilla::PluginBundle::BAREFOOT with Dist::Zilla::Role::PluginBundle::
 	use Dist::Zilla::Plugin::CheckVersionIncrement	0.121750	();
 	#use Dist::Zilla::Plugin::MetaProvides::Package	1.14		();		# hides DB/main/private packages
 	use Dist::Zilla::Plugin::MetaProvides::Class	2.001		();		# adds 'provides' to META.* for `class`
+	use Dist::Zilla::Plugin::PodnameFromClassname				();		# stops Pod::Weaver from complaining
 	use Dist::Zilla::Plugin::CheckChangesHasContent				();
 
 
-	our $VERSION = '0.04'; # VERSION
+	our $VERSION = '0.05'; # VERSION
 
 	my @dirty_files = qw< dist.ini Changes >;
 	my @exclude_generated_files = qw< README.pod META.json >;
@@ -77,6 +78,7 @@ provided $self->auto_prereq,
 			#
 			# file munging
 			OurPkgVersion				=>
+			PodnameFromClassname		=>
 			#InsertCopyright				=>
 			[ PodWeaver					=>	{ config_plugin => '@BAREFOOT', } ],
 
@@ -88,7 +90,7 @@ provided $self->auto_prereq,
 												location	=> 'root',
 											}
 			],
-			[ Bugtracker				=>	{ web => 'http://github.com/me/%l/issues' } ],
+			[ Bugtracker				=>	{ web => 'http://github.com/barefootcoder/%l/issues' } ],
 
 #			# generated xt/ tests
 #provided not $self->no_spellcheck,
@@ -181,7 +183,7 @@ Dist::Zilla::PluginBundle::BAREFOOT - Dist::Zilla configuration the way BAREFOOT
 
 =head1 VERSION
 
-This document describes version 0.04 of Dist::Zilla::PluginBundle::BAREFOOT.
+This document describes version 0.05 of Dist::Zilla::PluginBundle::BAREFOOT.
 
 =head1 SYNOPSIS
 
@@ -222,7 +224,7 @@ This is a L<Dist::Zilla> PluginBundle.  It is roughly equivalent to the followin
  
  	; should this be in metadata section?
  	[Bugtracker]
- 	web = http://github.com/me/%l/issues
+ 	web = http://github.com/barefootcoder/%l/issues
  
  	; xt tests
  	;[Test::PodSpelling]					; xt/author/pod-spell.t
@@ -398,7 +400,7 @@ Buddy Burden <barefoot@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is Copyright (c) 2015 by Buddy Burden.
+This software is Copyright (c) 2016 by Buddy Burden.
 
 This is free software, licensed under:
 
